import itertools
import uuid
from datetime import datetime,date
from django.db import models
from django.contrib.auth import get_user_model
from django.db.models.signals import post_save, pre_save
from django.dispatch import receiver
from django.utils.text import slugify
from django.core.mail import EmailMessage

from django_countries.fields import CountryField

from djangoldp.models import Model
from djangoldp_conversation.models import Conversation

from risefor_lobbying.models import Countrie,ActionGroup


User = get_user_model()




class organisationSupport(Model):
  """Allow citizens to sign a text that is in an action group"""
  created_at = models.DateTimeField(auto_now_add=True)
  name = models.CharField(max_length=100, verbose_name=u"Nom de l'organisme")
  website = models.CharField(max_length=100, verbose_name=u"Site internet", null=True, blank=True)
  logo = models.URLField(verbose_name=u"Image", null=True, blank=True)
  #supported_email = models.ForeignKey(TextSupporters_Email, related_name="supported_email", blank=True, null=True)
  class Meta:
    serializer_fields = ['@id','name','website','logo']
    nested_fields=[]
    anonymous_perms = ['view','add']
    authenticated_perms = ['inherit','view', 'add']
    ordering=['-created_at']

  def __str__(self):
      return self.name

class imageToShare(Model):
  title = models.URLField(verbose_name=u"Image", null=True, blank=True)

  class Meta:
    serializer_fields = ['@id','title']
    anonymous_perms = ['view']
    authenticated_perms = ['inherit', 'add']

  def __str__(self):
      return self.title

class conditionTag(Model):
  name = models.CharField(max_length=100, verbose_name=u"Tag name")
  class Meta:
    serializer_fields = ['@id','name']
  def __str__(self):
      return self.name


class riseforInstance(Model):
  name = models.CharField(max_length=150, verbose_name=u"nom du déploiement")
  image = models.URLField(verbose_name=u"Image", null=True, blank=True)
  description = models.TextField(verbose_name=u"Description de l'argument", null=True, blank=True)
  plateformLink = models.URLField(verbose_name=u"Link to site", null=True, blank=True)
  
  class Meta:
    serializer_fields = ['@id','name','image','description','plateformLink']
    anonymous_perms = ['view']
    authenticated_perms = ['inherit', 'add']
    ordering = ['?']

  def __str__(self):
    return self.name

class moduleStatus(Model):
  name = models.CharField(max_length=150, verbose_name=u"Etat du module")
  class Meta:
    serializer_fields = ['@id','name']
    anonymous_perms = ['view']
    authenticated_perms = ['inherit', 'add']
    ordering = ['name']

  def __str__(self):
    return self.name


class module(Model):
  name = models.CharField(max_length=150, verbose_name=u"nom du déploiement")
  description = models.TextField(verbose_name=u"Description de l'argument", null=True, blank=True)
  availabilityStatus = models.ForeignKey(moduleStatus, null=True, verbose_name=u"availabilityStatus", on_delete=models.SET_NULL)
  pictogram = models.CharField(max_length=150, verbose_name=u"Pictogram",null=True, blank=True)

  class Meta:
    serializer_fields = ['@id','name',"description","availabilityStatus",'pictogram']
    nested_fields = ["availabilityStatus"]
    anonymous_perms = ['view']
    authenticated_perms = ['inherit', 'add']
    ordering = ['name']

  def __str__(self):
    return self.name
  

class relatedInstance(Model):
  name = models.CharField(max_length=150, verbose_name=u"nom du déploiement")
  country = CountryField()
  url = models.URLField(verbose_name=u"Url", null=True, blank=True)

  class Meta:
    serializer_fields = ['@id','name','country','url']
    nested_fields = []
    anonymous_perms = ['view']
    authenticated_perms = ['inherit', 'add']
    ordering = ['name']

  def __str__(self):
    return self.name
  